/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ambari.server.utils;

import java.util.stream.Stream;

/**
 * Utilities for Streams
 */
public class StreamUtils {

  /**
   * Filters a stream for instances of a class and returns a typed stream
   * @param stream the stream to filter
   * @param clazz stream will be filtered to instances of this class
   * @param <T> the type of the class
   * @return A stream of containing only instances of {@link T}
   */
  public static <T> Stream<T> instancesOf(Stream<?> stream, Class<? extends T> clazz) {
    return stream.filter(clazz::isInstance).map(clazz::cast);
  }

}
